<?php

namespace Drupal\vidstack_player\Plugin\Field\FieldFormatter;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Shared trait for Vidstack Player video formatters.
 */
trait VidstackPlayerFormatterTrait {

  use StringTranslationTrait;

  /**
   * Returns the settings which are shared between formatters.
   *
   * @param array $form
   *   The form array.
   *
   * @return array
   *   The shared settings to reduce duplicate code.
   */
  public function getSharedSettings(array $form) {
    $form['autoplay'] = [
      '#title' => $this->t('Autoplay'),
      '#type' => 'checkbox',
      '#description' => $this->t('Play the video immediately upon page load. This is generally advised against on UX grounds. It is also disabled by default in some browsers.'),
      '#default_value' => $this->getSetting('autoplay'),
    ];
    $form['loop'] = [
      '#title' => $this->t('Loop'),
      '#type' => 'checkbox',
      '#description' => $this->t('Loop the video.'),
      '#default_value' => $this->getSetting('loop'),
    ];
    $form['muted'] = [
      '#title' => $this->t('Muted'),
      '#type' => 'checkbox',
      '#description' => $this->t('Start the video muted.'),
      '#default_value' => $this->getSetting('muted'),
    ];
    $form['controls'] = [
      '#title' => $this->t('Default controls'),
      '#type' => 'checkbox',
      '#description' => $this->t('Show the default controls of the video (e.g. from the browser itself or a provider like YouTube).'),
      '#default_value' => $this->getSetting('controls'),
    ];
    $form['load'] = [
      '#title' => $this->t('Load strategy'),
      '#type' => 'select',
      '#options' => [
        'eager' => $this->t('Load immediately'),
        'idle' => $this->t('Load after the page is loaded'),
        'visible' => $this->t('Load after becoming visible'),
        'play' => $this->t('Load after hitting play'),
      ],
      '#description' => $this->t('The load strategy that will be used to determine when the video content should start loading.'),
      '#default_value' => $this->getSetting('load'),
    ];
    return $form;
  }

  /**
   * Returns the default settings which are shared between formatters.
   *
   * @return array
   *   The shared default settings to reduce duplicate code.
   */
  public static function getSharedDefaultSettings() {
    return [
      'autoplay' => FALSE,
      'loop' => FALSE,
      'muted' => FALSE,
      'controls' => FALSE,
      'load' => 'visible',
    ];
  }

}
